/* 
    Test Score Display Customization
    Author: Roger Sprik and James Parsons
    PS Version checked: 10.1.3
*/
define(['angular', 'components/shared/index'], function (angular) {
	var myApp = angular.module('myModule', ['powerSchoolModule']);
	
	myApp.controller('testScoresController', function($scope, $http) {

		$scope.testScores = [];
		$scope.subTests = [];
		$scope.metadata = [];
		
		$scope.getTestScores = function(frn, id, name, config, suppress_zero) {
		    
		    $scope.testScores[id] = [];
		    $scope.subTests[id] = [];
		    $scope.metadata[id] = [];

		    testids = config.testid;
		    
		    console.log('suppress_zero=' + suppress_zero);

    		$http.get('tsd_testscores.json?frn=' + frn + '&testids=' + testids + '&suppress_zero=' + suppress_zero).then(function(retJSON) {
    		    retJSON.data.pop();

    		    var results = {};
    		    var headers = {};
    		    var nodata = true;
    		    
    		    // pivot subscores for unique test date (YYDDD as key)
    		    retJSON.data.forEach( function(row) {

    		        // create the row key for pivoting
    		        var key = row.test_key;
    		        results[key] = results[key] || {}; // this makes the results[key] an object, if not already one
    		        
    		        // add in the grouped values for each unique row
    		        results[key]['studentsdcid'] = row.studentsdcid;
    		        results[key]['student_test_id'] = row.student_test_id;
    		        results[key]['test_date'] = row.test_date;
    		        results[key]['grade_level'] = row.grade_level;
    		        results[key]['test_name'] = row.test_name;
    		        results[key]['sub_scores'] = results[key]['sub_scores'] || {};
    		        
    		        // is this subtest selected for display?  num, pct, or abc
    		        if( config.subtests[row.subtest_id].num || config.subtests[row.subtest_id].pct || config.subtests[row.subtest_id].abc ) {

    		            // set nodata to false
    		            nodata = false;
    		            
        		        // add in the pivoted values based on subtest_key (as column)
        		        var column = row.subtest_key;
    		            if (config.subtests[row.subtest_id].head) {
    		                // set alternate column header key if selected in the config
    		                row.subtest_name = config.subtests[row.subtest_id].head;
    		                column = config.subtests[row.subtest_id].head.replace(/[^0-9a-z]/gi, '');
    		            }

        		        var scores = { 'subject_name':row.subtest_name,
        		                       'is_num': config.subtests[row.subtest_id].num,
        		                       'numscore':row.numscore,
        		                       'is_pct': config.subtests[row.subtest_id].pct,
        		                       'is_sym': config.subtests[row.subtest_id].sym,
        		                       'pctscore':row.percentscore,
        		                       'is_abc': config.subtests[row.subtest_id].abc,
        		                       'abcscore':row.alphascore
        		                     };
        		        results[key]['sub_scores'][column] = scores;
        		        
        		        // copy subtest_name to headers array
        		        headers[column] = header[column] || {}; // this makes the headers[column] an object, if not already one
        		        headers[column]['key'] = column;
        		        if (config.subtests[row.subtest_id].head) {
        		            // set alternate column header label if selected in the config
        		            headers[column]['name'] = config.subtests[row.subtest_id].head;
        		        } else {
        		            headers[column]['name'] = row.subtest_name;
        		        }

    		        }

    		    });

                $scope.testScores[id] = results;
                $scope.subTests[id] = headers;
                $scope.metadata[id].name = name;
                $scope.metadata[id].gridfoot = config.gridfoot.replace(/\n/g,"<br>");
                $scope.metadata[id].nodata = nodata;

    		});
		};

		$scope.getSetup = function(schoolid, frn)  {

            // get setup and loop through each configuration
            $http.get('tsd_setup.json?schoolid=' + schoolid).then(function(retJSON) {
                retJSON.data.pop();
                retJSON.data.forEach( function(row) {
                    
                    // call the getTestScores for each grid
                    console.log('suppress_zero=' + row.config_suppress_zero);
                    $scope.getTestScores(frn, row.config_id, row.config_name, row.config, row.config_suppress_zero);
                    
                });
            });

		}		

	});

});
